Learn R Programming

ssifs (version 1.0.5)

smokingcessation: Stochastic Search Inconsistency Factor Selection of interventions for smoking cessation

Description

Stochastic Search Inconsistency Factor Selection for the evaluation of the consistency assumption for the network meta-analysis model.

These data are used as an example in Dias et al. (2013).

Arguments

Format

A data frame with the following columns:

event1number of individuals with successful smoking cessation in arm 1
n1number of individuals in arm 1
event2number of individuals with successful smoking cessation in arm 2
n2number of individuals in arm 2
event3number of individuals with successful smoking cessation in arm 3
n3number of individuals in arm 3
treat1treatment 1
treat2treatment 2
treat3treatment 3

Examples

Run this code
data(smokingcessation)

# Transform data from arm-based format to contrast-based format

smokingcessation$id <- 1:dim(smokingcessation)[1]
smoking.pair <- meta::pairwise(
  treat = list(treat1, treat2, treat3),
  event = list(event1, event2, event3),
  n = list(n1, n2, n3),
  studlab = id,
  data = smokingcessation,
  sm = "OR"
)

TE <- smoking.pair$TE
seTE <- smoking.pair$seTE
studlab <- smoking.pair$studlab
treat1 <- smoking.pair$treat1
treat2 <- smoking.pair$treat2

# Stochastic Search Inconsistency Factor Selection using as reference treatment A and the
# design-by-treatment method for the specification of the Z matrix.

m <- ssifs(TE, seTE, treat1, treat2, studlab, ref = "A",
M = 1000, B = 100, M_pilot = 1000, B_pilot = 100)

Run the code above in your browser using DataLab