data(smokingcessation)
# Transform data from arm-based format to contrast-based format
smokingcessation$id <- 1:dim(smokingcessation)[1]
smoking.pair <- meta::pairwise(
treat = list(treat1, treat2, treat3),
event = list(event1, event2, event3),
n = list(n1, n2, n3),
studlab = id,
data = smokingcessation,
sm = "OR"
)
TE <- smoking.pair$TE
seTE <- smoking.pair$seTE
studlab <- smoking.pair$studlab
treat1 <- smoking.pair$treat1
treat2 <- smoking.pair$treat2
# Stochastic Search Inconsistency Factor Selection using as reference treatment A and the
# design-by-treatment method for the specification of the Z matrix.
m <- ssifs(TE, seTE, treat1, treat2, studlab, ref = "A",
M = 1000, B = 100, M_pilot = 1000, B_pilot = 100)
Run the code above in your browser using DataLab